==> krdc-4.14.3.tar.xz: krdc-4.14.3/konsole/konsoleviewfactory.h <==
/****************************************************************************
**
** Copyright (C) 2009 Urs Wolfer <uwolfer @ kde.org>
**
** This file is part of KDE.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; see the file COPYING. If not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
** Boston, MA 02110-1301, USA.
**
****************************************************************************/

#ifndef KONSOLEVIEWFACTORY_H
#define KONSOLEVIEWFACTORY_H

#include "remoteviewfactory.h"

#include "konsoleview.h"

class KonsoleViewFactory : public RemoteViewFactory
{
    Q_OBJECT

public:
    explicit KonsoleViewFactory(QObject *parent, const QVariantList &args);

    virtual ~KonsoleViewFactory();

    virtual bool supportsUrl(const KUrl &url) const;

    virtual RemoteView *createView(QWidget *parent, const KUrl &url, KConfigGroup configGroup);

    virtual HostPreferences *createHostPreferences(KConfigGroup configGroup, QWidget *parent);

    virtual QString scheme() const;

    virtual QString connectActionText() const;
    
    virtual QString connectButtonText() const;

    virtual QString connectToolTipText() const;
};

#endif // KONSOLEVIEWFACTORY_H

==> krdc-16.04.0.tar.xz: krdc-16.04.0/konsole/konsoleviewfactory.h <==
/****************************************************************************
**
** Copyright (C) 2009 Urs Wolfer <uwolfer @ kde.org>
**
** This file is part of KDE.
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; see the file COPYING. If not, write to
** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
** Boston, MA 02110-1301, USA.
**
****************************************************************************/

#ifndef KONSOLEVIEWFACTORY_H
#define KONSOLEVIEWFACTORY_H

#include "remoteviewfactory.h"

#include "konsoleview.h"

class KonsoleViewFactory : public RemoteViewFactory
{
    Q_OBJECT

public:
    explicit KonsoleViewFactory(QObject *parent, const QVariantList &args);

    virtual ~KonsoleViewFactory();

    virtual bool supportsUrl(const QUrl &url) const;

    virtual RemoteView *createView(QWidget *parent, const QUrl &url, KConfigGroup configGroup);

    virtual HostPreferences *createHostPreferences(KConfigGroup configGroup, QWidget *parent);

    virtual QString scheme() const;

    virtual QString connectActionText() const;

    virtual QString connectButtonText() const;

    virtual QString connectToolTipText() const;
};

#endif // KONSOLEVIEWFACTORY_H
